@@ -166,7 +166,7 @@ class PycURLLibrary():
         
         Equivalent for <--capath> argument with curl
         """
-        self._url.get_context().set_capath(cacertDirectory)
+        self._url.get_context().set_capath(str(cacertDirectory))
         
     def cert(self, cert):
         """(SSL) Tells curl to use the specified client certificate file when getting a file with HTTPS, 
@@ -174,7 +174,7 @@ class PycURLLibrary():
 
         Equivalent for <--cert> argument with curl
         """
-        self._url.get_context().set_cert(cert)
+        self._url.get_context().set_cert(str(cert))
         
     def key(self, key):
         """(SSL/SSH) Private key file name. 
@@ -182,7 +182,7 @@ class PycURLLibrary():
 
         Equivalent for <--key> argument with curl
         """
-        self._url.get_context().set_key(key)
+        self._url.get_context().set_key(str(key))
         
     def perform(self):
         """Perform curl perform.
